@@ -65,8 +65,9 @@ LaunchDarklyParams: OrgParams = {
         "dev": Profile(
             display_name="Dev",
             region="us-east-1",
-            arn="arn:aws:iam::506919356135:role/ops/SSHAdmin-dev",
+            arn="arn:aws:iam::506919356135:role/ops/SSHAdmin-development",
             ansible_bucket="launchdarkly-sym-ansible-dev",
+            aliases=["development"],
         ),
         "shared-services": Profile(
             display_name="Shared Services",
