@@ -1,4 +1,5 @@
 import pytest
+from sym.shared.cli.helpers.contexts import push_env
 from sym.shared.cli.tests.helpers.capture import CaptureCommand
 
 from sym.cli.errors import SuppressedError
@@ -23,7 +24,8 @@ def start_session_stub(make_stub):
 
 @pytest.fixture
 def ssh_session_tester(command_tester):
-    return command_tester(["ssh-session", "test", "--instance", INSTANCE_ID])
+    with push_env("SYM_SKIP_ENSURE_KEY", "1"):
+        yield command_tester(["ssh-session", "test", "--instance", INSTANCE_ID])
 
 
 def test_ssh_session(ssh_session_tester, capture_command: CaptureCommand):
