@@ -70,7 +70,7 @@ def test_check_after_a_day(pipx_updater, time_travel):
 def test_get_version(updater):
     assert updater.get_latest_version() is not None
     assert updater.get_latest_version().major == 0
-    assert updater.get_latest_version().minor == 0
+    assert updater.get_latest_version().minor == 1
 
 
 def test_needs_update(pipx_updater):
@@ -116,11 +116,13 @@ def test_update_pipx_failed(pipx_updater, capture_command):
 def test_update_brew(brew_updater, capture_command):
     capture_command.register_output(r"brew --repo", "/foo/bar")
     with capture_command():
+        brew_updater.latest_version = V1
         assert brew_updater._update() == True
     capture_command.assert_command(
         ["brew", "--repo", "symopsio/tap"],
         ["git", "pull", "origin", "master"],
-        ["brew", "upgrade", "sym"],
+        ["brew", "install", "sym@0.0.1"],
+        ["brew", "link", "sym@0.0.1"],
     )
 
 
@@ -140,15 +142,16 @@ def test_update_brew_failed_debug(brew_updater, capture_command, capsys):
 
 def test_update_brew_timeout(brew_updater, capture_command, capsys):
     capture_command.register_output(r"brew --repo", "/foo/bar")
-    capture_command.register_output(r"brew upgrade", "something slow...", timeout=True)
+    capture_command.register_output(r"brew install", "something slow...", timeout=True)
     with capture_command():
+        brew_updater.latest_version = V1
         brew_updater.debug = True
         assert brew_updater._update() == False
 
     capture_command.assert_command(
         ["brew", "--repo", "symopsio/tap"],
         ["git", "pull", "origin", "master"],
-        ["brew", "upgrade", "sym"],
+        ["brew", "install", "sym@0.0.1"],
         ["brew", "link", "sym"],
     )
 
